==> kscreen-5.8.8-1-src.tar.xz: kscreen-5.8.8/kcm/kcm_kscreen.desktop.cmake <==
[Desktop Entry]
Exec=kcmshell5 kcm_kscreen
Icon=preferences-desktop-display-randr
Type=Service
X-KDE-ServiceTypes=KCModule
X-KDE-Library=kcm_kscreen
X-KDE-ParentApp=kcontrol
X-KDE-System-Settings-Parent-Category=display
X-KDE-Weight=40
X-KDE-PluginInfo-Version=@KSCREEN_VERSION@

Name=Displays
Name[ca]=Pantalles
Name[ca@valencia]=Pantalles
Name[cs]=Obrazovky
Name[da]=Skærme
Name[de]=Anzeigen
Name[el]=Οθόνες
Name[en_GB]=Displays
Name[es]=Pantallas
Name[et]=Monitorid
Name[eu]=Bistaratzaileak
Name[fi]=Näytöt
Name[fr]=Affichages
Name[he]=תצוגות
Name[id]=Displays
Name[it]=Schermi
Name[ko]=디스플레이
Name[lt]=Ekranai
Name[nl]=Schermen
Name[nn]=Skjermar
Name[pl]=Ekrany
Name[pt]=Ecrãs
Name[pt_BR]=Telas
Name[ru]=Экраны
Name[sk]=Obrazovky
Name[sl]=Zasloni
Name[sr]=Екрани
Name[sr@ijekavian]=Екрани
Name[sr@ijekavianlatin]=Ekrani
Name[sr@latin]=Ekrani
Name[sv]=Bildskärmar
Name[uk]=Дисплеї
Name[x-test]=xxDisplaysxx
Name[zh_CN]=显示
Name[zh_TW]=顯示
Comment=Manage and configure monitors and displays
Comment[ar]=أدر واضبط الشّاشات والعروض
Comment[ast]=Xestiona y configura los monitores y pantalles
Comment[bs]=Upravljanje i konfiguracija monitora i ekrana
Comment[ca]=Gestiona i configura els monitors i pantalles
Comment[ca@valencia]=Gestiona i configura els monitors i pantalles
Comment[cs]=Spravovat a nastavit monitory a zobrazení
Comment[da]=Håndtér og indstil monitorer og skærme
Comment[de]=Verwaltung und Einrichtung vom Monitoren und Anzeigen
Comment[el]=Διαχείριση και διαμόρφωση οθονών και απεικονίσεων
Comment[en_GB]=Manage and configure monitors and displays
Comment[es]=Gestionar y configurar monitores y pantallas
Comment[et]=Monitoride ja ekraanide haldamine ja seadistamine
Comment[eu]=Kudeatu eta konfiguratu monitoreak eta bistaratzaileak
Comment[fi]=Näyttöjen asetusten hallinta
Comment[fr]=Gère et configure les moniteurs et les écrans
Comment[gl]=Xestiona a configura os monitores e a resolución
Comment[he]=נהל את הגדרות המסכים והתצוגות שלך
Comment[hu]=Monitorok és kijelzők kezelése és beállítása
Comment[id]=Kelola dan atur monitor dan display
Comment[it]=Gestisci e configura monitor e schermi
Comment[ko]=모니터와 디스플레이 설정 및 관리
Comment[lt]=Tvarkyti ir konfigūruoti monitorius ir ekranus
Comment[nb]=Håndter og sett opp monitorer og skjermer
Comment[nl]=Monitoren en schermen beheren en instellen
Comment[nn]=Set opp skjermar og skjermbilete
Comment[pa]=ਮਾਨੀਟਰ ਤੇ ਡਿਸਪਲੇਅ ਦਾ ਪਰਬੰਧ ਤੇ ਸੰਰਚਨਾ ਕਰੋ
Comment[pl]=Zarządzanie i ustawienia ekranów
Comment[pt]=Faz a gestão e configuração dos monitores e ecrãs
Comment[pt_BR]=Gerencia e configura monitores e telas
Comment[ro]=Gestionează și configurează monitoare și afișaje
Comment[ru]=Настройка экранов и видеовыходов
Comment[sk]=Správa a nastavenie monitorov a obrazoviek
Comment[sl]=Upravljajte in nastavljajte zaslone in prikazovalnike
Comment[sr]=Управљање и подешавање монитора̂ и екрана̂
Comment[sr@ijekavian]=Управљање и подешавање монитора̂ и екрана̂
Comment[sr@ijekavianlatin]=Upravljanje i podešavanje monitorâ̂ i ekranâ̂
Comment[sr@latin]=Upravljanje i podešavanje monitorâ̂ i ekranâ̂
Comment[sv]=Hantera och ställ in bildskärmar
Comment[tr]=Ekranları ve görüntüleri yönet, yapılandır
Comment[uk]=Керування і налаштовування моніторів і дисплеїв
Comment[x-test]=xxManage and configure monitors and displaysxx
Comment[zh_CN]=管理和配置显示和监视器
Comment[zh_TW]=管理與設定螢幕與顯示
X-KDE-Keywords=display,monitor,scale,scaling,resolution,orientation,outputs
X-KDE-Keywords[ast]=pantalla,pantalles,monitores,monitor,escalar,escala,escaláu,resolución,orientación,salíes,salida
X-KDE-Keywords[ca]=pantalla,monitor,escala,escalat,resolució,orientació,sortides
X-KDE-Keywords[ca@valencia]=pantalla,monitor,escala,escalat,resolució,orientació,eixides
X-KDE-Keywords[da]=skærm,monitor,skaler,opløsning,orientering,output
X-KDE-Keywords[de]=Anzeige,Monitor,Bildschirm,Skalierung,Auflösung,Ausrichtung,Ausgabe
X-KDE-Keywords[el]=απεικόνιση,οθόνη,κλίμακα,κλιμάκωση,ανάλυση,προσανατολισμός,έξοδοι
X-KDE-Keywords[en_GB]=display,monitor,scale,scaling,resolution,orientation,outputs
X-KDE-Keywords[es]=pantalla,monitor,escala,escalado,resolución,orientación,salidas
X-KDE-Keywords[et]=kuva,monitor,ekraan,skaleerimine,lahutusvõime,eraldusvõime,orientatsioon,väljundid
X-KDE-Keywords[eu]=bistaratzaile,monitore,eskalatu,eskalatze,bereizmen,orientazioa,irteerak
X-KDE-Keywords[fi]=display,monitor,scale,scaling,resolution,orientation,outputs,näyttö,monitori,skaalaus,resoluutio,tarkkuus,suunta,kierto,ulostulot
X-KDE-Keywords[fr]=affichage,moniteur,échelle,mise à l'échelle,résolution,orientation,sorties
X-KDE-Keywords[gl]=display,pantalla,monitor,scale,escala,scaling,escalar,resolution,resolución,orientation,orientación,outputs,saída,saídas
X-KDE-Keywords[he]=display,monitor,scale,scaling,resolution,orientation,outputs,תצוגה,מוניטור,רצולוציה,כיוון
X-KDE-Keywords[id]=display,monitor,scale,scaling,resolution,orientation,outputs
X-KDE-Keywords[it]=schermo,monitor,scala,riscalatura,risoluzione,orientazione,uscite
X-KDE-Keywords[ko]=display,monitor,scale,scaling,resolution,orientation,outputs,디스플레이,모니터,비율,배율,해상도,출력,방향
X-KDE-Keywords[lt]=ekranas,vaizduoklis,monitorius,mastelis,skiriamoji geba,padėtis,orientacija,išvedimas
X-KDE-Keywords[nl]=scherm,monitor,schaal,schalen,resolutie,oriëntatie,uitvoer
X-KDE-Keywords[nn]=skjermbilete,skjerm,skala,skalering,oppløysing,skjermoppløysing,retning,utgang
X-KDE-Keywords[pl]=wyświetlacz,monitor,skala,skalowanie,rozdzielczość,kierunek,orientacja,wyjścia
X-KDE-Keywords[pt]=ecrã,monitor,escala,resolução,orientação,saídas
X-KDE-Keywords[pt_BR]=tela,monitor,escala,ajuste,resolução,orientação,saídas
X-KDE-Keywords[ru]=display,monitor,scale,scaling,resolution,orientation,outputs,экран,монитор,масштаб,разрешение,ориентация,выводы
X-KDE-Keywords[sk]=displej,monitor,mierka,škálovanie,rozlíšenie,orientácia,výstupy
X-KDE-Keywords[sl]=prikaz,zaslon,monitor,umerjanje,merilo,ločljivost,resolucija,orientacija,usmerjenost,izhodi
X-KDE-Keywords[sr]=display,monitor,scale,scaling,resolution,oritentation,outputs,приказ,монитор,екран,скалирање,резолуција,оријентација,излаз
X-KDE-Keywords[sr@ijekavian]=display,monitor,scale,scaling,resolution,oritentation,outputs,приказ,монитор,екран,скалирање,резолуција,оријентација,излаз
X-KDE-Keywords[sr@ijekavianlatin]=display,monitor,scale,scaling,resolution,oritentation,outputs,prikaz,monitor,ekran,skaliranje,rezolucija,orijentacija,izlaz
X-KDE-Keywords[sr@latin]=display,monitor,scale,scaling,resolution,oritentation,outputs,prikaz,monitor,ekran,skaliranje,rezolucija,orijentacija,izlaz
X-KDE-Keywords[sv]=skärm,bildskärm,skala,skalning,upplösning,orientering,utgångar
X-KDE-Keywords[uk]=display,monitor,scale,scaling,resolution,orientation,outputs,дисплей,монітор,масштаб,масштабування,роздільність,здатність,орієнтація,виведення,виходи
X-KDE-Keywords[x-test]=xxdisplayxx,xxmonitorxx,xxscalexx,xxscalingxx,xxresolutionxx,xxorientationxx,xxoutputsxx
X-KDE-Keywords[zh_CN]=display,monitor,scale,scaling,resolution,orientation,outputs,显示,监视器,缩放,分辨率,旋转,方位,输出
X-KDE-Keywords[zh_TW]=display,monitor,scale,scaling,resolution,orientation,outputs

==> kscreen-5.8.9-1-src.tar.xz: kscreen-5.8.9/kcm/kcm_kscreen.desktop.cmake <==
[Desktop Entry]
Exec=kcmshell5 kcm_kscreen
Icon=preferences-desktop-display-randr
Type=Service
X-KDE-ServiceTypes=KCModule
X-KDE-Library=kcm_kscreen
X-KDE-ParentApp=kcontrol
X-KDE-System-Settings-Parent-Category=display
X-KDE-Weight=40
X-KDE-PluginInfo-Version=@KSCREEN_VERSION@

Name=Displays
Name[ca]=Pantalles
Name[ca@valencia]=Pantalles
Name[cs]=Obrazovky
Name[da]=Skærme
Name[de]=Anzeigen
Name[el]=Οθόνες
Name[en_GB]=Displays
Name[es]=Pantallas
Name[et]=Monitorid
Name[eu]=Bistaratzaileak
Name[fi]=Näytöt
Name[fr]=Affichages
Name[he]=תצוגות
Name[id]=Displays
Name[it]=Schermi
Name[ko]=디스플레이
Name[lt]=Ekranai
Name[nl]=Schermen
Name[nn]=Skjermar
Name[pl]=Ekrany
Name[pt]=Ecrãs
Name[pt_BR]=Telas
Name[ru]=Экраны
Name[sk]=Obrazovky
Name[sl]=Zasloni
Name[sr]=Екрани
Name[sr@ijekavian]=Екрани
Name[sr@ijekavianlatin]=Ekrani
Name[sr@latin]=Ekrani
Name[sv]=Bildskärmar
Name[uk]=Дисплеї
Name[x-test]=xxDisplaysxx
Name[zh_CN]=显示
Name[zh_TW]=顯示
Comment=Manage and configure monitors and displays
Comment[ar]=أدر واضبط الشّاشات والعروض
Comment[ast]=Xestiona y configura los monitores y pantalles
Comment[bs]=Upravljanje i konfiguracija monitora i ekrana
Comment[ca]=Gestiona i configura els monitors i pantalles
Comment[ca@valencia]=Gestiona i configura els monitors i pantalles
Comment[cs]=Spravovat a nastavit monitory a zobrazení
Comment[da]=Håndtér og indstil monitorer og skærme
Comment[de]=Verwaltung und Einrichtung vom Monitoren und Anzeigen
Comment[el]=Διαχείριση και διαμόρφωση οθονών και απεικονίσεων
Comment[en_GB]=Manage and configure monitors and displays
Comment[es]=Gestionar y configurar monitores y pantallas
Comment[et]=Monitoride ja ekraanide haldamine ja seadistamine
Comment[eu]=Kudeatu eta konfiguratu monitoreak eta bistaratzaileak
Comment[fi]=Näyttöjen asetusten hallinta
Comment[fr]=Gère et configure les moniteurs et les écrans
Comment[gl]=Xestiona a configura os monitores e a resolución
Comment[he]=נהל את הגדרות המסכים והתצוגות שלך
Comment[hu]=Monitorok és kijelzők kezelése és beállítása
Comment[id]=Kelola dan konfigurasi monitor dan display
Comment[it]=Gestisci e configura monitor e schermi
Comment[ko]=모니터와 디스플레이 설정 및 관리
Comment[lt]=Tvarkyti ir konfigūruoti monitorius ir ekranus
Comment[nb]=Håndter og sett opp monitorer og skjermer
Comment[nl]=Monitoren en schermen beheren en instellen
Comment[nn]=Set opp skjermar og skjermbilete
Comment[pa]=ਮਾਨੀਟਰ ਤੇ ਡਿਸਪਲੇਅ ਦਾ ਪਰਬੰਧ ਤੇ ਸੰਰਚਨਾ ਕਰੋ
Comment[pl]=Zarządzanie i ustawienia ekranów
Comment[pt]=Faz a gestão e configuração dos monitores e ecrãs
Comment[pt_BR]=Gerencia e configura monitores e telas
Comment[ro]=Gestionează și configurează monitoare și afișaje
Comment[ru]=Настройка экранов и видеовыходов
Comment[sk]=Správa a nastavenie monitorov a obrazoviek
Comment[sl]=Upravljajte in nastavljajte zaslone in prikazovalnike
Comment[sr]=Управљање и подешавање монитора̂ и екрана̂
Comment[sr@ijekavian]=Управљање и подешавање монитора̂ и екрана̂
Comment[sr@ijekavianlatin]=Upravljanje i podešavanje monitorâ̂ i ekranâ̂
Comment[sr@latin]=Upravljanje i podešavanje monitorâ̂ i ekranâ̂
Comment[sv]=Hantera och ställ in bildskärmar
Comment[tr]=Ekranları ve görüntüleri yönet, yapılandır
Comment[uk]=Керування і налаштовування моніторів і дисплеїв
Comment[x-test]=xxManage and configure monitors and displaysxx
Comment[zh_CN]=管理和配置显示和监视器
Comment[zh_TW]=管理與設定螢幕與顯示
X-KDE-Keywords=display,monitor,scale,scaling,resolution,orientation,outputs
X-KDE-Keywords[ast]=pantalla,pantalles,monitores,monitor,escalar,escala,escaláu,resolución,orientación,salíes,salida
X-KDE-Keywords[ca]=pantalla,monitor,escala,escalat,resolució,orientació,sortides
X-KDE-Keywords[ca@valencia]=pantalla,monitor,escala,escalat,resolució,orientació,eixides
X-KDE-Keywords[da]=skærm,monitor,skaler,opløsning,orientering,output
X-KDE-Keywords[de]=Anzeige,Monitor,Bildschirm,Skalierung,Auflösung,Ausrichtung,Ausgabe
X-KDE-Keywords[el]=απεικόνιση,οθόνη,κλίμακα,κλιμάκωση,ανάλυση,προσανατολισμός,έξοδοι
X-KDE-Keywords[en_GB]=display,monitor,scale,scaling,resolution,orientation,outputs
X-KDE-Keywords[es]=pantalla,monitor,escala,escalado,resolución,orientación,salidas
X-KDE-Keywords[et]=kuva,monitor,ekraan,skaleerimine,lahutusvõime,eraldusvõime,orientatsioon,väljundid
X-KDE-Keywords[eu]=bistaratzaile,monitore,eskalatu,eskalatze,bereizmen,orientazioa,irteerak
X-KDE-Keywords[fi]=display,monitor,scale,scaling,resolution,orientation,outputs,näyttö,monitori,skaalaus,resoluutio,tarkkuus,suunta,kierto,ulostulot
X-KDE-Keywords[fr]=affichage,moniteur,échelle,mise à l'échelle,résolution,orientation,sorties
X-KDE-Keywords[gl]=display,pantalla,monitor,scale,escala,scaling,escalar,resolution,resolución,orientation,orientación,outputs,saída,saídas
X-KDE-Keywords[he]=display,monitor,scale,scaling,resolution,orientation,outputs,תצוגה,מוניטור,רצולוציה,כיוון
X-KDE-Keywords[id]=display,monitor,scale,scaling,resolution,orientation,outputs
X-KDE-Keywords[it]=schermo,monitor,scala,riscalatura,risoluzione,orientazione,uscite
X-KDE-Keywords[ko]=display,monitor,scale,scaling,resolution,orientation,outputs,디스플레이,모니터,비율,배율,해상도,출력,방향
X-KDE-Keywords[lt]=ekranas,vaizduoklis,monitorius,mastelis,skiriamoji geba,padėtis,orientacija,išvedimas
X-KDE-Keywords[nl]=scherm,monitor,schaal,schalen,resolutie,oriëntatie,uitvoer
X-KDE-Keywords[nn]=skjermbilete,skjerm,skala,skalering,oppløysing,skjermoppløysing,retning,utgang
X-KDE-Keywords[pl]=wyświetlacz,monitor,skala,skalowanie,rozdzielczość,kierunek,orientacja,wyjścia
X-KDE-Keywords[pt]=ecrã,monitor,escala,resolução,orientação,saídas
X-KDE-Keywords[pt_BR]=tela,monitor,escala,ajuste,resolução,orientação,saídas
X-KDE-Keywords[ru]=display,monitor,scale,scaling,resolution,orientation,outputs,экран,монитор,масштаб,разрешение,ориентация,выводы
X-KDE-Keywords[sk]=displej,monitor,mierka,škálovanie,rozlíšenie,orientácia,výstupy
X-KDE-Keywords[sl]=prikaz,zaslon,monitor,umerjanje,merilo,ločljivost,resolucija,orientacija,usmerjenost,izhodi
X-KDE-Keywords[sr]=display,monitor,scale,scaling,resolution,oritentation,outputs,приказ,монитор,екран,скалирање,резолуција,оријентација,излаз
X-KDE-Keywords[sr@ijekavian]=display,monitor,scale,scaling,resolution,oritentation,outputs,приказ,монитор,екран,скалирање,резолуција,оријентација,излаз
X-KDE-Keywords[sr@ijekavianlatin]=display,monitor,scale,scaling,resolution,oritentation,outputs,prikaz,monitor,ekran,skaliranje,rezolucija,orijentacija,izlaz
X-KDE-Keywords[sr@latin]=display,monitor,scale,scaling,resolution,oritentation,outputs,prikaz,monitor,ekran,skaliranje,rezolucija,orijentacija,izlaz
X-KDE-Keywords[sv]=skärm,bildskärm,skala,skalning,upplösning,orientering,utgångar
X-KDE-Keywords[uk]=display,monitor,scale,scaling,resolution,orientation,outputs,дисплей,монітор,масштаб,масштабування,роздільність,здатність,орієнтація,виведення,виходи
X-KDE-Keywords[x-test]=xxdisplayxx,xxmonitorxx,xxscalexx,xxscalingxx,xxresolutionxx,xxorientationxx,xxoutputsxx
X-KDE-Keywords[zh_CN]=display,monitor,scale,scaling,resolution,orientation,outputs,显示,监视器,缩放,分辨率,旋转,方位,输出
X-KDE-Keywords[zh_TW]=display,monitor,scale,scaling,resolution,orientation,outputs
